@@ -110,11 +110,12 @@ class HiveTableLastUpdatedExtractor(Extractor):
     """
 
     # Additional where clause for non partitioned table SQL
-    # ADDTIONAL_WHERE_CLAUSE = """ NOT EXISTS (SELECT * FROM PARTITIONS WHERE PARTITIONS.TBL_ID = TBLS.TBL_ID)
-    # AND NOT EXISTS (SELECT * FROM PARTITION_KEYS WHERE PARTITION_KEYS.TBL_ID = TBLS.TBL_ID)
-    # """
+    DEFAULT_ADDTIONAL_WHERE_CLAUSE = """ NOT EXISTS (SELECT * FROM PARTITIONS WHERE PARTITIONS.TBL_ID = TBLS.TBL_ID)
+    AND NOT EXISTS (SELECT * FROM PARTITION_KEYS WHERE PARTITION_KEYS.TBL_ID = TBLS.TBL_ID)
+    """
 
-    ADDTIONAL_WHERE_CLAUSE = """ NOT EXISTS (SELECT * FROM "PARTITIONS" p WHERE p."TBL_ID" = t."TBL_ID")
+    DEFAULT_POSTGRES_ADDTIONAL_WHERE_CLAUSE = """ NOT EXISTS (SELECT * FROM "PARTITIONS" p WHERE p."TBL_ID" = t."TBL_ID")
+    AND NOT EXISTS (SELECT * FROM "PARTITION_KEYS" pk WHERE pk."TBL_ID" = t."TBL_ID")
     """
 
     DATABASE = 'hive'
@@ -187,17 +188,20 @@ class HiveTableLastUpdatedExtractor(Extractor):
 
         :return: SQLAlchemyExtractor
         """
+
+        default_sql_stmt, default_additional_where_clause = self._choose_default_non_partitioned_sql_stm()
+
         if self.NON_PARTITIONED_TABLE_WHERE_CLAUSE_SUFFIX_KEY in self._conf:
             where_clause_suffix = """
             {}
             AND {}
             """.format(self._conf.get_string(
                 self.NON_PARTITIONED_TABLE_WHERE_CLAUSE_SUFFIX_KEY),
-                self.ADDTIONAL_WHERE_CLAUSE)
+                default_additional_where_clause)
         else:
-            where_clause_suffix = 'WHERE {}'.format(self.ADDTIONAL_WHERE_CLAUSE)
+            where_clause_suffix = 'WHERE {}'.format(default_additional_where_clause)
 
-        sql_stmt = self._choose_default_non_partitioned_sql_stm().format(
+        sql_stmt = default_sql_stmt.format(
             where_clause_suffix=where_clause_suffix)
 
         LOGGER.info('SQL for non-partitioned table against Hive metastore: %s', sql_stmt)
@@ -211,9 +215,9 @@ class HiveTableLastUpdatedExtractor(Extractor):
     def _choose_default_non_partitioned_sql_stm(self) -> str:
         url = make_url(self._conf.get_string("extractor.sqlalchemy.conn_string"))
         if url.drivername.lower() in ['postgresql', 'postgres']:
-            return self.DEFAULT_POSTGRES_NON_PARTITIONED_TABLE_SQL_STATEMENT
+            return self.DEFAULT_POSTGRES_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_POSTGRES_ADDTIONAL_WHERE_CLAUSE
         else:
-            return self.DEFAULT_NON_PARTITIONED_TABLE_SQL_STATEMENT
+            return self.DEFAULT_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_ADDTIONAL_WHERE_CLAUSE
 
     def _get_filesystem(self) -> FileSystem:
         fs = FileSystem()
